@@ -63,18 +63,18 @@ async def discover_devices(timeout=RESPONSE_SEC):
     return devices
 
 
-async def discover_single(host: str, password: str, ssl: bool, use_websockets: bool) -> SwidgetDevice:
+async def discover_single(host: str, token_name: str, password: str, ssl: bool, use_websockets: bool) -> SwidgetDevice:
     """Discover a single device by the given IP address.
 
     :param host: Hostname of device to query
     :rtype: SwidgetDevice
     :return: Object for querying/controlling found device.
     """
-    swidget_device = SwidgetDevice(host, password, ssl, use_websockets)
+    swidget_device = SwidgetDevice(host, token_name, password, ssl, use_websockets)
     await swidget_device.get_summary()
     device_type = swidget_device.device_type
     device_class = _get_device_class(device_type)
-    dev = device_class(host, password, False, use_websockets)
+    dev = device_class(host, token_name, password, False, use_websockets)
     await dev.update()
     return dev
 
