@@ -70,6 +70,7 @@ class SwidgetWebsocket:
                 self.send_str(json.dumps({"type": "summary", "request_id": "1"}))
                 self.send_str(json.dumps({"type": "state", "request_id": "2"}))
                 async for message in self.ws_client:
+                    _LOGGER.error(f'AIOHTTP websocket message {message.type}')
                     if self.state == STATE_STOPPED:
                         break
 
@@ -86,6 +87,7 @@ class SwidgetWebsocket:
                         break
 
         except aiohttp.ClientResponseError as error:
+            _LOGGER.error(f'AIOHTTP ClientResponseError')
             if error.code == 401:
                 _LOGGER.error(f"Credentials rejected: {error}")
                 self._error_reason = ERROR_AUTH_FAILURE
@@ -94,6 +96,7 @@ class SwidgetWebsocket:
                 self._error_reason = ERROR_UNKNOWN
             self.state = STATE_STOPPED
         except (aiohttp.ClientConnectionError, asyncio.TimeoutError) as error:
+            _LOGGER.error(f'AIOHTTP ClientConnectionError, asyncio.TimeoutError')
             if self.failed_attempts >= MAX_FAILED_ATTEMPTS:
                 self._error_reason = ERROR_TOO_MANY_RETRIES
                 self.state = STATE_STOPPED
@@ -104,6 +107,7 @@ class SwidgetWebsocket:
                 self.state = STATE_DISCONNECTED
                 await asyncio.sleep(retry_delay)
         except Exception as error:  # pylint: disable=broad-except
+            _LOGGER.error(f'AIOHTTP Exception')
             if self.state != STATE_STOPPED:
                 _LOGGER.exception(f"Unexpected exception occurred: {error}")
                 self._error_reason = ERROR_UNKNOWN
